pub struct OgImagePlugin { /* private fields */ }Expand description
Plugin that auto-generates Open Graph social card images.
Implementations
Sourceimpl OgImagePlugin
impl OgImagePlugin
Sourcepub fn new(base_url: impl Into<String>) -> Self
pub fn new(base_url: impl Into<String>) -> Self
Creates a new OgImagePlugin with default branding.
Examples
use ssg::og_image::OgImagePlugin;
use ssg::plugin::Plugin;
let p = OgImagePlugin::new("https://example.com");
assert_eq!(p.name(), "og-image");Sourcepub fn with_colors(
base_url: impl Into<String>,
brand_color: impl Into<String>,
text_color: impl Into<String>,
) -> Self
pub fn with_colors( base_url: impl Into<String>, brand_color: impl Into<String>, text_color: impl Into<String>, ) -> Self
Creates a plugin with custom brand colours.
Examples
use ssg::og_image::OgImagePlugin;
use ssg::plugin::Plugin;
let p = OgImagePlugin::with_colors("https://example.com", "#000", "#fff");
assert_eq!(p.name(), "og-image");Trait Implementations
Sourceimpl Clone for OgImagePlugin
impl Clone for OgImagePlugin
Sourcefn clone(&self) -> OgImagePlugin
fn clone(&self) -> OgImagePlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OgImagePlugin
impl Debug for OgImagePlugin
Sourceimpl Plugin for OgImagePlugin
impl Plugin for OgImagePlugin
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn transform_html(
&self,
html: &str,
_path: &Path,
_ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, _path: &Path, _ctx: &PluginContext, ) -> Result<String, SsgError>
Per-file HTML transform hook — called once per HTML file during
the fused transform pass. Read more
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for OgImagePlugin
impl RefUnwindSafe for OgImagePlugin
impl Send for OgImagePlugin
impl Sync for OgImagePlugin
impl Unpin for OgImagePlugin
impl UnsafeUnpin for OgImagePlugin
impl UnwindSafe for OgImagePlugin